==> piwigo-2.2.3.zip: piwigo/language/ru_RU/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Установка';
$lang['Basic configuration'] = 'Базовая настройка';
$lang['Default gallery language'] = 'Язык по умолчанию';
$lang['Database configuration'] = 'Настройка базы данных';
$lang['Admin configuration'] = 'Настройка администрирования';
$lang['Start Install'] = 'Начать установку';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'адрес электронной почты должен быть похож на xxx@yyy.eee (например: jack@altern.org)';
$lang['Webmaster login'] = 'Логин вебмастера';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Он будет показан посетителям. Необходим для администрирования сайта';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Успешно соединились с сервером, но невозможно подключиться к базе данных';
$lang['Can\'t connect to server'] = 'Невозможно соединиться с сервером';
$lang['Host'] = 'Хост MySQL';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Пользователь';
$lang['user login given by your host provider'] = 'логин, который выдал провайдер';
$lang['Password'] = 'Пароль';
$lang['user password given by your host provider'] = 'пароль, который выдал провайдер';
$lang['Database name'] = 'Имя базы данных';
$lang['also given by your host provider'] = 'также выдается провайдером. Часто совпадает с логином';
$lang['Database table prefix'] = 'Префикс таблиц в базе данных';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'названия таблиц в базе данных будут начинаться с этого (что упростит их обслуживание)';
$lang['enter a login for webmaster'] = 'нужно ввести логин для вебмастера';
$lang['webmaster login can\'t contain characters \' or "'] = 'логин вебмастера не должен содержать символы  \' или "';
$lang['please enter your password again'] = 'еще раз пароль';
$lang['Webmaster password'] = 'Пароль вебмастера';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Не сообщайте его никому, он необходим для доступа к панели администрирования';
$lang['Password [confirm]'] = 'Повторите пароль';
$lang['verification'] = 'еще раз для исключения опечатки';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Нужна помощь? Задайте свои вопросы на <a href="%s">Форуме Piwigo</a>.';
$lang['Webmaster mail address'] = 'Электронная почта вебмастера';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Будет использоваться для контакта посетителей с администратором';
$lang['Database type'] = 'Тип базы данных';
$lang['The type of database your piwigo data will be store in'] = 'Тип базы данных будет храниться в';
$lang['PHP 5 is required'] = 'Требуется PHP 5';
$lang['It appears your webhost is currently running PHP %s.'] = 'Кажется, что Ваш хостинг в настоящее время под управлением  PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo может попытаться переключить Вашу конфигурацию на PHP 5, создавая или изменяя .htaccess файл.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Отметьте, что Вы можете изменить конфигурацию самостоятельно и перезапустите Piwigo после этого.';
$lang['Try to configure PHP 5'] = 'Попытаться переконфигурировать PHP 5';
$lang['Sorry!'] = 'Извините!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo не в состоянии переконфигурировать PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Вы должны обратиться к своему провайдеру за поддержой и разъяснениями  как Вы можете переключиться на PHP 5.';
$lang['Hope to see you back soon.'] = 'Надеемся скоро увидеть Вас вновь.';
$lang['Congratulations, Piwigo installation is completed'] = 'Поздравляем, установка Piwigo полностью завершена';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Альтернативное решение состоит в том, чтобы скопировать текст в блоке выше и вставить это в файл "local/config/database.inc.php"   (Предупреждение: database.inc.php должен только содержать то, что находится в textarea, без линий возврата строки или пробелов)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Создать файл конфигурации local/config/database.inc.php не удалось.';
$lang['Download the config file'] = 'Загрузить файл конфигурации';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Вы можете загрузить файл конфигурации и передать его в local/config directory.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite и PostgreSQL в настоящее время находятся в стадии эксперимента.';
$lang['Learn more'] = 'Узнать больше';
?>

==> piwigo-2.5.1.zip: piwigo/language/ru_RU/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Установка';
$lang['Basic configuration'] = 'Базовая настройка';
$lang['Default gallery language'] = 'Язык по умолчанию';
$lang['Database configuration'] = 'Настройка базы данных';
$lang['Admin configuration'] = 'Настройка администрирования';
$lang['Start Install'] = 'Начать установку';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'адрес электронной почты должен быть похож на xxx@yyy.eee (например: jack@altern.org)';
$lang['Webmaster login'] = 'Логин вебмастера';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Он будет показан посетителям. Необходим для администрирования сайта';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Успешно соединились с сервером, но невозможно подключиться к базе данных';
$lang['Can\'t connect to server'] = 'Невозможно соединиться с сервером';
$lang['Host'] = 'Хост MySQL';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Пользователь';
$lang['user login given by your host provider'] = 'логин, который выдал провайдер';
$lang['Password'] = 'Пароль';
$lang['user password given by your host provider'] = 'пароль, который выдал провайдер';
$lang['Database name'] = 'Имя базы данных';
$lang['also given by your host provider'] = 'также выдается провайдером. Часто совпадает с логином';
$lang['Database table prefix'] = 'Префикс таблиц в базе данных';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'названия таблиц в базе данных будут начинаться с этого (что упростит их обслуживание)';
$lang['enter a login for webmaster'] = 'нужно ввести логин для вебмастера';
$lang['webmaster login can\'t contain characters \' or "'] = 'логин вебмастера не должен содержать символы  \' или "';
$lang['please enter your password again'] = 'еще раз пароль';
$lang['Webmaster password'] = 'Пароль вебмастера';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Не сообщайте его никому, он необходим для доступа к панели администрирования';
$lang['Password [confirm]'] = 'Повторите пароль';
$lang['verification'] = 'еще раз для исключения опечатки';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Нужна помощь? Задайте свои вопросы на <a href="%s">Форуме Piwigo</a>.';
$lang['Webmaster mail address'] = 'Электронная почта вебмастера';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Будет использоваться для контакта посетителей с администратором';
$lang['PHP 5 is required'] = 'Требуется PHP 5';
$lang['It appears your webhost is currently running PHP %s.'] = 'Кажется, что Ваш хостинг в настоящее время под управлением  PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo может попытаться переключить Вашу конфигурацию на PHP 5, создавая или изменяя .htaccess файл.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Отметьте, что Вы можете изменить конфигурацию самостоятельно и перезапустите Piwigo после этого.';
$lang['Try to configure PHP 5'] = 'Попытаться переконфигурировать PHP 5';
$lang['Sorry!'] = 'Извините!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo не в состоянии переконфигурировать PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Вы должны обратиться к своему провайдеру за поддержой и разъяснениями  как Вы можете переключиться на PHP 5.';
$lang['Hope to see you back soon.'] = 'Надеемся скоро увидеть Вас вновь.';
$lang['Congratulations, Piwigo installation is completed'] = 'Поздравляем, установка Piwigo полностью завершена';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Альтернативное решение состоит в том, чтобы скопировать текст в блоке выше и вставить это в файл "local/config/database.inc.php"   (Предупреждение: database.inc.php должен только содержать то, что находится в textarea, без линий возврата строки или пробелов)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Создать файл конфигурации local/config/database.inc.php не удалось.';
$lang['Download the config file'] = 'Загрузить файл конфигурации';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Вы можете загрузить файл конфигурации и передать его в local/config directory.';
$lang['Just another Piwigo gallery'] = 'Еще одна галерея Piwigo';
$lang['Welcome to my photo gallery'] = 'Добро пожаловать в мою фотогалерею';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Пожалуйста консультируйтесь на нашем форуме для любой помощи:';
$lang['Welcome to your new installation of Piwigo!'] = 'Добро пожаловать в новую установку Piwigo!';
?>
